I like to store a lot of Wendelstein 7-X (and other machine-) related calculations in plain files, with the filenames containing most information about the contents.

This situation is not perfect, but allows easy interoperation with a variety of codes, while providing the neccessary semantic information.

This package is intended as a bridging solution towards a future implementation of a database, by both documenting the filename format I like to use as code, and being able to parse it in a large variety of variations, as well as emitting a "canonical" variant of its encoding.
